%define releasebase 5
%define nbase fftw
%define prefix /opt/%{nbase}2/%{version}/%{compilertag}
%define modulepath /opt/Modules/modulefiles/

#Use as deafults if no command line inputs
%define as_limulus 1
%define use_gnu4  1
# allow --with[out] <feature> at rpm command line build
%{?_with_gnu3: %{expand: %%define use_gnu3 1}}
%{?_with_gnu4: %{expand: %%define use_gnu4 1}}
%{?_with_pgi: %{expand: %%define use_pgi 1}}
%{?_with_intel: %{expand: %%define use_intel 1}}
%{?_with_pathsc: %{expand: %%define use_pathsc 1}}
%{?_with_basement: %{expand: %%define as_basement 1}}
%{?_with_limulus: %{expand: %%define as_limulus 1}}
#pick the target
%if "1" == "%{as_basement}"
%define targetbase Basement
%else
%define targetbase Limulus
%endif
# pick the compiler
%if "1" == "%{use_gnu4}"
%define compilertag gnu4
%define openMP  --without-openmp
%ifarch i386
%define fftw2hacks   --enable-i386-hacks 
%endif
%ifarch X86_64
%define fftw2hacks --disable-i386-hacks  
%endif
%endif
%if "1" == "%{use_pgi}"
%define compilertag pgi
%define openMP  --with-openmp
%define fftw2hacks --disable-i386-hacks
%endif
%if "1" == "%{use_intel}"
%define compilertag intel
%endif
%if "1" == "%{use_pathsc}"
%define compilertag pathsc
%endif
%if "1" == "%{use_gnu3}"
%define compilertag gnu3
%define openMP  --without-openmp
%ifarch i386
%define fftw2hacks  --enable-i386-hacks 
%endif
%ifarch X86_64
%define fftw2hacks --disable-i386-hacks  
%endif
%endif
Name: %{nbase}2-%{compilertag}

Summary: Fast Fourier Transform library
Version: 2.1.5
Group: %{targetbase}/Libraries
Release: %{releasebase}.%{targetbase}
License: GPL
URL: http://www.fftw.org/
Packager: deadline@basement-supercomputing.com
Vendor: Basement-Supercomputing.com
Source: %{nbase}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
Requires: modules
BuildRequires: modules

%description
FFTW is a C subroutine library for computing the Discrete Fourier Transform
(DFT) in one or more dimensions, of both real and complex data, and of
arbitrary input size. We believe that FFTW, which is free software, should
become the FFT library of choice for most applications. Our benchmarks,
performed on on a variety of platforms, show that FFTW's performance is
typically superior to that of other publicly available FFT software.

This package also contains the header files, static libraries and development
documentation for %{name}. It has been configured to work in
the Warewulf Cluster environment. In this case only static libaries
are included. 

NOTE: This package does not include the MPI libraries. There is a 
separate package for each MPI version. 

%prep
%setup -q -c  %{nbase}-%{version}
mv %{nbase}-%{version} single
cp -a single double


%build
rpm -qf /opt/Modules/bin/modulecmd >& /dev/null
if [ $? -ne 0 ]; then
  echo "This RPM requries the BSC Modules package to build"
fi
. /etc/profile.d/modules.sh

%if "1" == "%{use_intel}"
echo "Intel Comp not implemented"
exit
%endif
%if "1" == "%{use_pgi}"
  	module load pgi62
				export CC=pgcc
        export F77=pgf77
        export OPENMP_CFLAGS='-mp'
        export CFLAGS='-fastsse -O3 '
        export FFLAGS='-fastsse -O3 '
%endif
%if "1" == "%{use_pathsc}"
echo "Path Comp not implemented"
exit
%endif
%if "1" == "%{use_gnu4}"
        export CC=gcc
        export CFLAGS='-O2 -D_FILE_OFFSET_BITS=64 -D_LARGEFILE64_SOURCE'
        export F77=gfortran
        export FFLAGS=' -O2'
%endif
%if "0" == "%{use_gnu3}"
        export CC=gcc
        export CFLAGS='-O2 -D_FILE_OFFSET_BITS=64 -D_LARGEFILE64_SOURCE'
        export F77=g77
        export FFLAGS=' -O2'
%endif
### build double
pushd double
./configure --prefix=%{prefix}  %{openMP} %{fftw2hacks} \
	 --with-pentium-timer  \
 	 --enable-threads 
%{__make} %{?_smp_mflags}
popd
pushd single
### build single
./configure --prefix=%{prefix}  %{openMP} %{fftw2hacks} \
	--with-pentium-timer  \
	--enable-threads \
	--enable-type-prefix \
	--enable-float 
%{__make} %{?_smp_mflags}
popd

%install
pushd double
        make  DESTDIR=%{buildroot} install
        cp -a AUTHORS COPYING COPYRIGHT ChangeLog NEWS README* TODO ../
        cp -a doc/ ../
        cp -a FAQ/ ../
popd
pushd single
        make  DESTDIR=%{buildroot} install
popd
# make sure we include the fortran incude file
/bin/cp single/fortran/fftw_f77.i %{buildroot}/%{prefix}/include

%post
/sbin/ldconfig 2>/dev/null
#create the module file
cat <<EOF >%{modulepath}/%{name}
#%Module1.0#######################################################################
## fftw2 modulefile
##

proc ModulesHelp { } {
        puts stderr "\tThis module loads the appropriate environment for "
        puts stderr "\tusing %{name} version %{version}.\n"
}

module-whatis "%{name} %{version}"
module-log error none

set fftw2root  %{prefix}

if [ module-info mode load ] {
	setenv FFTW2_PATH \$fftw2root/lib
	setenv FFTW2_INCLUDE \$fftw2root/include
        append-path INFOPATH \$fftw2root/info
}
if [ module-info mode remove ] {
	unsetenv FFTW2_PATH 
	unsetenv FFTW2_INCLUDE
        remove-path INFOPATH \$fftw2root/info
}
EOF

%postun
/sbin/ldconfig 2>/dev/null
/bin/rm %{modulepath}/%{name}

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%doc AUTHORS COPYING COPYRIGHT ChangeLog NEWS README* TODO doc/*.gif doc/*.html doc/*.ps FAQ/fftw-faq.html/
#%doc %{_infodir}/*.info*
#%{prefix}/etc/ld.so.conf/%{nbase}-%{version}
%{prefix}/include/*.h
%{prefix}/include/*.i
%{prefix}/lib/*.a
%{prefix}/info/*
%exclude %{prefix}/lib/*.la

%changelog
